@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.17';
+    $VERSION  = '0.18';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -37,7 +37,7 @@ sub new
             $class->import;
         };
         if ($@) {
-            warn "Could not find or compile '$class'\n";
+            warn "Could not find or compile '$class'\n" if $^W;
         } else {
             $self->{RENDERER} = $class;
             last;
